'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var kebabCase = require('lodash/fp/kebabCase');

var mapValues = require('lodash/fp/mapValues');

var curry = require('lodash/fp/curry');

function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}

var kebabCase__default = /*#__PURE__*/_interopDefaultLegacy(kebabCase);

var mapValues__default = /*#__PURE__*/_interopDefaultLegacy(mapValues);

var curry__default = /*#__PURE__*/_interopDefaultLegacy(curry);

var idCounter = {};

function uniqueId(prefix) {
  if (prefix === void 0) {
    prefix = '$highlightUi$';
  }

  if (!idCounter[prefix]) {
    idCounter[prefix] = 0;
  }

  idCounter[prefix] += 1;
  var id = idCounter[prefix];

  if (prefix === '$highlightUi$') {
    return "" + id;
  }

  return "" + prefix + id;
}

var noop = function () {};

function invariant(condition, message) {
  if (process.env.NODE_ENV !== 'development') {
    return;
  }

  if (!condition) {
    var error = new Error(message);
    error.name = 'Invariant Violation';
    throw error;
  }
}

var forkHandlers = function (handlers) {
  return function (e) {
    handlers.forEach(function (handler) {
      if (handler) handler(e);
    });
  };
};

function parseMetadata(metadata) {
  return metadata ? Object.keys(metadata).reduce(function (acc, key) {
    acc["data-" + kebabCase__default["default"](key)] = metadata[key] || '';
    return acc;
  }, {}) : {};
}
/**
 * This function allows to generate a new object that
 * contains metadata with values suffixed with provided suffix
 *
 * @example
 *   ```ts
 *   suffixMetadata(metadata, 'inner')
 *   ```
 *
 * This function is curried:
 *
 * @example
 *   ```ts
 *   const { metadata } = props;
 *   const suffixedMeta = suffixMetadata(metadata);
 *   ...
 *   <div {...parseMetadata(suffixedMeta('innerPart1'))}>
 *     <div {...parseMetadata(suffixedMeta('innerPart2'))} />
 *   </div>
 *   ```
 *
 * @param {ComponentMetadata} metadata The original metadata object
 * @param {string} suffix A string to be added to the values of the original metadata object
 * @returns {ComponentMetadata} The metadata object with values containing suffixes
 */


var suffixMetadata = curry__default["default"](function (metadata, suffix) {
  return mapValues__default["default"](function (val) {
    return val + "-" + suffix;
  }, metadata);
});
exports.forkHandlers = forkHandlers;
exports.invariant = invariant;
exports.noop = noop;
exports.parseMetadata = parseMetadata;
exports.suffixMetadata = suffixMetadata;
exports.uniqueId = uniqueId;
//# sourceMappingURL=index.js.map
